import argparse

from clippy.cookbook import Cookbook
from clippy.exceptions import AutomationError

from rover.netbox import Netbox
from rover.virt import find_hv_cluster, find_vm_hypervisor


class Reboot(Cookbook):
    """Safely reboots a node."""

    def argument_parser(self) -> argparse.ArgumentParser:
        parser = super().argument_parser()
        parser.add_argument("query")
        parser.add_argument("--force", help="force reset the VM", action="store_true")
        return parser

    def execute(self) -> int:
        remote = self.clippy.remote_hosts(self.args.query)
        self.logger.info("Rebooting %s", remote)
        if self.args.force:
            if len(remote) != 1:
                raise AutomationError("--force does not support multiple hosts")
            fqdn = str(remote)

            netbox = Netbox.from_config(self.clippy.config("netbox"))
            hv_name = find_vm_hypervisor(netbox, fqdn)
            virt_cluster, hv = find_hv_cluster(netbox, self.clippy.remote, hv_name)

            virt_cluster.reset_vm(hv, fqdn)
        else:
            remote.reboot()

        return 0
